package main

import androidx.compose.foundation.layout.*
import androidx.compose.material.Button
import androidx.compose.material.ButtonDefaults
import androidx.compose.material.MaterialTheme
import androidx.compose.material.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.unit.dp

@Composable
fun choixLangagePage(
    languageManager: LanguageManager,
    onBackClick: () -> Unit,
    onPythonClick: () -> Unit,
    onJavaClick: () -> Unit,
    onJavaScriptClick: () -> Unit
) {

    Column(
        modifier = Modifier.fillMaxSize(),
        verticalArrangement = Arrangement.Top, // Align content at the top
        horizontalAlignment = Alignment.CenterHorizontally
    ) {
        Text(text = languageManager.getLanguageChoiceTitle(), style = MaterialTheme.typography.h3)
    }

    Column(
        modifier = Modifier
            .fillMaxSize()  // Fills the maximum available width
            .padding(50.dp),
        // Align the content in the center vertically and horizontally
        verticalArrangement = Arrangement.Center,
        horizontalAlignment = Alignment.CenterHorizontally

    ) {
        Button(
            onClick = onPythonClick,
            modifier = Modifier
                .width(125.dp),
            colors = ButtonDefaults.buttonColors(
                backgroundColor = customRedColor,
                contentColor = Color.White
            ),
            enabled = false
        ) {
            Text("Python")
        }

        Button(
            onClick = onJavaClick,
            modifier = Modifier
                .width(125.dp),
            colors = ButtonDefaults.buttonColors(
                backgroundColor = customRedColor,
                contentColor = Color.White
            ),
            enabled = false
        ) {
            Text("Java")
        }

        Button(
            onClick = onJavaScriptClick,
            modifier = Modifier
                .width(125.dp),
            colors = ButtonDefaults.buttonColors(
                backgroundColor = customRedColor,
                contentColor = Color.White
            )
        ) {
            Text("JavaScript")
        }
    }

    Column(
        modifier = Modifier.fillMaxSize().padding(20.dp),
        verticalArrangement = Arrangement.Bottom,
        horizontalAlignment = Alignment.CenterHorizontally
    ) {
        Button(
            onClick = onBackClick,
            colors = ButtonDefaults.buttonColors(
                backgroundColor = customRedColor,
                contentColor = Color.White
            )
        ) {
            Text(languageManager.getBackButtonText())
        }
    }

}